/*
 * Filesystem object opening functionality.
 *
 * Copyright (C) 2018, 2019, 2020 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <fsclient/fsdesc.h>
#include <fsserver/accessor.h>
#include <fsserver/resource.h>



/* A mix-in providing support for opening objects. */

class OpenerSupport
{
public:
  /* A mechanism for obtaining filesystem references from objects. */

  virtual long getfs_object(fs_object_t *fsobj, l4_cap_idx_t *fs)
  {
    (void) fsobj; (void) fs;
    return -L4_EACCESS;
  }

  /* A mechanism for mounting filesystem objects. */

  virtual long mount_object(fs_object_t *fsobj, l4_cap_idx_t fs)
  {
    (void) fsobj; (void) fs;
    return -L4_EACCESS;
  }

  /* A mechanism for obtaining filesystem objects. */

  virtual long open_object(fs_object_t *fsobj, int flags, size_t *size,
                           l4_cap_idx_t *file);

  /* A mechanism for obtaining resources for filesystem objects. */

  virtual long open_object_resource(fs_object_t *fsobj, int flags,
                                    Resource **resource)
  {
    (void) fsobj; (void) flags; (void) resource;
    return -L4_EACCESS;
  }
};
